GOOSE Messages don't use the length field to perform the dissection.
[obnox/wireshark/wip.git] / cfile.h
diff --git a/cfile.h b/cfile.h
index b3a21473478b341ee384f6630180487caa222af3..730da187c78064797a9dccebbbac4264b81ba7e7 100644 (file)
--- a/cfile.h
+++ b/cfile.h
 #ifndef __CFILE_H__
 #define __CFILE_H__
 
+#include "frame_data_sequence.h"
+
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 /* Current state of file. */
 typedef enum {
   FILE_CLOSED,                 /* No file open */
@@ -41,18 +47,38 @@ typedef enum {
   /* add EBCDIC when it's implemented */
 } search_charset_t;
 
+typedef enum {
+  SD_FORWARD,
+  SD_BACKWARD
+} search_direction;
+
+/*
+ * We store the frame_data structures in a radix tree, with 1024
+ * elements per level.  The leaf nodes are arrays of 1024 frame_data
+ * structures; the nodes above them are arrays of 1024 pointers to
+ * the nodes below them.  The capture_file structure has a pointer
+ * to the root node.
+ *
+ * As frame numbers are 32 bits, and as 1024 is 2^10, that gives us
+ * up to 4 levels of tree.
+ */
+#define LOG2_NODES_PER_LEVEL   10
+#define NODES_PER_LEVEL                (1<<LOG2_NODES_PER_LEVEL)
+
 typedef struct _capture_file {
   file_state   state;           /* Current state of capture file */
   gchar       *filename;        /* Name of capture file */
+  gchar       *source;          /* Temp file source, e.g. "Pipe from elsewhere" */
   gboolean     is_tempfile;     /* Is capture file a temporary file? */
   gboolean     user_saved;      /* If capture file is temporary, has it been saved by user yet? */
   gint64       f_datalen;       /* Size of capture file data (uncompressed) */
   guint16      cd_t;            /* File type of capture file */
   int          lnk_t;           /* Link-layer type with which to save capture */
-  guint32      vers;            /* Version.  For tcpdump minor is appended to major */
-  int          count;           /* Total number of frames */
-  int          displayed_count; /* Number of displayed frames */
-  int          marked_count;    /* Number of marked frames */
+  guint32      count;           /* Total number of frames */
+  guint32      displayed_count; /* Number of displayed frames */
+  guint32      marked_count;    /* Number of marked frames */
+  guint32      ignored_count;   /* Number of ignored frames */
+  guint32      ref_time_count;  /* Number of time referenced frames */
   gboolean     drops_known;     /* TRUE if we know how many packets were dropped */
   guint32      drops;           /* Dropped packets */
   nstime_t     elapsed_time;    /* Elapsed time */
@@ -63,38 +89,38 @@ typedef struct _capture_file {
   gchar       *dfilter;         /* Display filter string */
   gboolean     redissecting;    /* TRUE if currently redissecting (cf_redissect_packets) */
   /* search */
-  gchar       *sfilter;         /* Search filter string */
-  gboolean     sbackward;       /* TRUE if search is backward, FALSE if forward */
-  gboolean     hex;             /* TRUE is raw data search is being performed */
-  gboolean     string;          /* TRUE is text search is being performed */
-  guint32      search_pos;      /* Position of last character found in search */
-  search_charset_t scs_type;    /* Character set for text search */
+  gchar       *sfilter;         /* Filter, hex value, or string being searched */
+  gboolean     hex;             /* TRUE if "Hex value" search was last selected */
+  gboolean     string;          /* TRUE if "String" search was last selected */
+  gboolean     summary_data;    /* TRUE if "String" search in "Packet list" (Info column) was last selected */
+  gboolean     decode_data;     /* TRUE if "String" search in "Packet details" was last selected */
+  gboolean     packet_data;     /* TRUE if "String" search in "Packet data" was last selected */
+  guint32      search_pos;      /* Byte position of last byte found in a hex search */
   gboolean     case_type;       /* TRUE if case-insensitive text search */
-  gboolean     decode_data;     /* TRUE if searching protocol tree text */
-  gboolean     summary_data;    /* TRUE if searching Info column text */
+  search_charset_t scs_type;    /* Character set for text search */
+  search_direction dir;         /* Direction in which to do searches */
+  gboolean     search_in_progress; /* TRUE if user just clicked OK in the Find dialog or hit <control>N/B */
   /* packet data */
   union wtap_pseudo_header pseudo_header; /* Packet pseudo_header */
   guint8       pd[WTAP_MAX_PACKET_SIZE];  /* Packet data */
-  /* memory chunks have been deprecated in favor of the slice allocator,
-   * which has been added in 2.10
-   */
-#if GLIB_CHECK_VERSION(2,10,0)
-
-#else
-  GMemChunk   *plist_chunk;     /* Memory chunk for frame_data structures */
-#endif
-  frame_data  *plist_start;     /* Packet list */
-  frame_data  *plist_end;       /* Last packet in list */
-  frame_data  *first_displayed; /* First frame displayed */
-  frame_data  *last_displayed;  /* Last frame displayed */
+  /* frames */
+  frame_data_sequence *frames;  /* Sequence of frames, if we're keeping that information */
+  guint32      first_displayed; /* Frame number of first frame displayed */
+  guint32      last_displayed;  /* Frame number of last frame displayed */
   column_info  cinfo;           /* Column formatting information */
   frame_data  *current_frame;   /* Frame data for current frame */
   gint         current_row;     /* Row number for current frame */
   epan_dissect_t *edt;          /* Protocol dissection for currently selected packet */
   field_info  *finfo_selected; /* Field info for currently selected field */
-  struct ph_stats_s* pstats;    /* accumulated stats (reset on redisplay in GUI)*/
+#ifdef WANT_PACKET_EDITOR
+  GTree       *edited_frames;   /* BST with modified frames */
+#endif
 } capture_file;
 
-void init_cap_file(capture_file *);
+extern void cap_file_init(capture_file *cf);
+
+#ifdef __cplusplus
+}
+#endif /* __cplusplus */
 
 #endif /* cfile.h */